# USER SETTINGS FOR BLUE IRIS LOGFILE WATCHDOG POWERSHELL SCRIPT
#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'BI_logfile_wdog.ps1'
#   2. This script must be located in the same folder as script 'BI_logfile_wdog.ps1'
#   3. This script is suitable for 'BI_logfile_wdog.ps1' versions V3+
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# ENTER DESTINATION PATH FOR SCRIPTS FILES
	# ... [string] like "D:\BI_logfile_wdog"
	$app_path = "YOUR_APP_PATH"

	# IF USING PUSHOVER

		# ENTER YOUR PUSHOVER API USER KEY
		# ... https://pushover.net/
		$po_user_token = "YOUR_API_USER_KEY"

		# ENTER YOUR PUSHOVER API APPLICATION TOKEN
		# ... https://pushover.net/ (scroll down to 'Your Applications')
		# ... TIP: consider adding a 'PowerShell' application to your https://pushover.net/ account
		$po_app_token = "YOUR_API_APPLICATION_TOKEN"

	# IF USING TELEGRAM
	
		# Setting up: 
		# Use the following link to create a new Telegram Bot token and a Blue Iris 'channel' chat id.
		# (I named my channel 'Blueiris_xxx' ... xxx = my initials) 
		# http://www.marrold.co.uk/2017/04/push-notifications-from-tasker-to.html
		
		# Notification customization: 
		# Unlike Pushover, Telegram does not support server-side customization of notifications (only device-side). 
		# So customizations must be set up on your device:
		# 1. Open the Telegram app on your device after receiving a notification
		# 2. Tap the channel name > Notifications > Customize
		# 3. Customize the sound, vibration, repeat frequency, and priority
		# 4. Restart your device (required for my Samsung Galaxy S24+)

		# ENTER YOUR TELEGRAM BOT API TOKEN
		# ... https://core.telegram.org/bots
		$tg_api_token = "YOUR_API_TOKEN"

		# ENTER YOUR TELEGRAM BOT CHAT ID
		# ... https://core.telegram.org/bots
		$tg_chat_id = "YOUR_CHAT_ID"
		
# OPTIONAL SETTINGS

	# SCRIPT OPTIONS

		# SET DEFAULT BATCH EVALUATION FILTER SET
		# ... this setting is an ALTERNATE to using the script's -BatchFile argument
		# ... if defined, script automatically uses these filter sets
		# ... expecting string array
		# ... for syntax, see provided file 'batch_mode_template.txt. 
		$my_default_filters = @()
		<# $my_default_filters = @(	
			'-FilterLevels="2"',
			'-FilterLevels="2";-FilterMsgs="free, -"',
			'-FilterMsgs="err|fail|died|debug|missing|undefined|quit|corrupt"'
			'-FilterMsgs="subscription"'
		) #>

		# OPT OUT OF BACKGROUND MESSAGING
		# ... expecting $false or $true (default = $true)
		# ... Key Points: 
		#     1. Background messages are enabled only if script is running in the background
		#     2. This global setting may be overridden by argument '-Quiet'
		$bg_msgs_on = $true
		#$bg_msgs_on = $false

	# ACCESSING THE BLUE IRIS WEB SERVER USING HTTP INTERFACE

		# NOTE: the script retrieves the Blue Iris web server address and port from the registry

		# OPT-IN TO USING CREDENTIALS FOR HTTP INTERFACE COMMANDS
		# ... expecting $false or $true (default = $false)
		# ... currently used for these HTTP commands: '/admin?log'
		$post_w_creds_flg = $false
		#$post_w_creds_flg = $true

		# IF THE ABOVE SETTING ABOVE IS TRUE
		
			# [REQUIRED] ENTER YOUR WEBSERVER'S USERNAME & PASSWORD CREDENTIALS
			# ... CREDENTIALS ARE REQUIRED TO ACCESS THE BLUE IRIS WEBSERVER VIA THE JSON INTERFACE
			# ... NOTE: ACCOUNT MUST BE ADMIN to use argument -Delete (which requires a database rebuild HTTP command)
			# ... NOTE: ACCOUNT MUST BE ADMIN if setting $post_to_BI_logfile_flg (below) is $true
			# ... NOTE: to use credentials, be sure to uncheck 'Use secure session keys and login page' 
			#     in Blue Iris settings: click Settings > Web server > Advanced
			# ... [string] 
			$bi_user_name = "YOUR_BI_USER_NAME"
			$bi_user_pw = "YOUR_BI_USER_PASSORD"
		
	# POSTING TO THE BLUE IRIS LOGFILE
	
		# This logging functionality is provided as a means to document automated actions.
		# FURTHERMORE, a setting is provided to limit logging to when the script is executed from the background 
		# (e.g., via Task Scheduler or Blue Iris actions).
		
		# BTW, even if you've enabled logging by default (via user setting $post_to_BI_logfile_flg below), 
		# logging can still be disabled on-demand -- via the script's -NoBiLog argument.

		# OPT-IN TO POSTING CUSTOM MESSAGES TO THE BLUE IRIS LOG
		# ... expecting $true or $false (default = $false)
		# ... NOTE: if value is $true, setting $bi_user_name (above) MUST BE ADMIN
		# ... NOTE: script parameter -NoBiLog can be used to temporarily override this setting (if $true)
		$post_to_BI_logfile_flg = $false
		#$post_to_BI_logfile_flg = $true

		# OPT-IN TO USING A CUSTOM LOGFILE 'SEVERITY' LEVEL
		# ... expecting integer >10 (default = 0 'informational')
		# ... WHY USE? a custom level can make it easier to filter/match logfile entries created by this script
		# ... HEADS-UP: custom levels will not have an icon in the Blue Iris Messages Log (Status > Log tab);
		#     if you sort the message log on the 1st column, all custom message will appear in a group 
		# ... HEADS-UP: script will ALWAYS use level 2 when pushing an error output to the Blue Iris logfile
		# ... KEY FOR BLUE IRIS RESERVED LEVELS
		#     0=informational, 1=warning, 2=error, 
		#     3=triggered/re-triggered/alerted, 
		#     4=disk allocation is OK ('free, +'); 'signal restored'
		#     7=new version available
		#     10=login/logout
		$custom_BI_logfile_level = 0
		#$custom_BI_logfile_level = 911

		# OPT-IN TO POSTING TO THE BLUE IRIS LOG ONLY FROM BACKGROUND
		# ... expecting $true or $false (default = $false)
		# ... $true avoids logging to Blue Iris logfile when using script from Console
		$post_to_BI_logfile_in_background_only_flg = $false
		#$post_to_BI_logfile_in_background_only_flg = $true

		# OPT-IN TO POSTING TO THE BLUE IRIS LOG ONLY IF MATCHES FOUND
		# ... expecting $true or $false (default = $false)
		# ... $true avoids EXCESSIVE logging to Blue Iris logfile when script finds no matching logfile entries
		$post_to_BI_logfile_w_matches_only_flg = $false
		#$post_to_BI_logfile_w_matches_only_flg = $true

	# LOGGING TO CSV FILE

		# OPT-OUT OF LOGGING SCRIPT EXECUTION TO SCRIPT'S CSV FILE
		# ... expecting $false or $true (default = $true)
		$log_to_csv_logfile_flg = $true
		#$log_to_csv_logfile_flg = $false

		# OPT-IN TO ONLY LOGGING TO SCRIPT'S CSV FILE ONLY IF MATCHES FOUND
		# ... expecting $false or $true (default = $false)
		# ... Ignored if $log_to_csv_logfile_flg = $false
		$log_only_events_to_csv_logfile_flg = $false
		#$log_only_events_to_csv_logfile_flg = $true

	# NOTIFICATION DEFAULTS

		# ENTER DEFAULT PUSH APPLICATION
		# ... expecting "Pushover", "Telegram", or "both"; case-insensitive (default is 'Pushover")
		# ... NOTE: may be overridden using argument -PushMethod
		$push_service = "Pushover"
		#$push_service = "Telegram"

		# ENTER DEFAULT NUMBER OF LOGFILE ENTRY MATCHES TO APPEND TO PUSH NOTIFICATIONS
		# ... expecting a positive integer (Default is 3)
		# ... 0 disables showing matched entries
		$push_row_matches_disp_max = 3
		#$push_row_matches_disp_max = 5

	# PUSHOVER NOTIFICATION DEFAULTS

		# ENTER PUSHOVER MESSAGE PRIORITY
		# ... (integer) -2|-1|0|1|2; -2=lowest, -1=low(silent), 0=normal, 1=high-priority, 2=emergency
		# ... default is 0
		# ... see https://pushover.net/api#priority
		$po_priority = 0
		#$po_priority = 2

		# ENTER PUSHOVER SOUND
		# ... default is "" (Pushover default sound)
		# ... see https://pushover.net/api#sounds
		$po_sound = ""  # default sound
		#$po_sound = "siren"  # built-in sound
		#$po_sound = "not-kiddin"  # custom sound

		# ENTER PUSHOVER DEVICE(S)
		# ... default is "" (All Pushover devices)
		# ... may be comma-delimited list.
		# ... see https://pushover.net/api
		$po_device = ""  # all devices
		#$po_device = "galaxy-s24"  # single device
		#$po_device = "galaxy-s24,iPhoneXS"  # multiple devices

		# ENTER PUSHOVER RETRY PARAMETER (SECONDS)
		# ... required for priority=2 messages (emergency)
		# ... default is 30
		# ... see https://pushover.net/api#priority
		$po_retry = 30

		# ENTER PUSHOVER EXPIRE PARAMETER (SECONDS)
		# ... required for priority=2 messages (emergency)
		# ... default is 300
		# ... see https://pushover.net/api#priority
		$po_expire = 300

		# ENTER PUSHOVER EMERGENCE PRIORITY TAGS
		# ... blank ("") is default tag
		# ... see https://pushover.net/api#priority
		#$po_tags = ""
		#$po_tags = "a=BI,c=&CAM,g=Front"  # custom tags
		$po_tags = "a=BI,c=&CAM"  # custom tags

# END USER SETTINGS
# ================================================
